class KetamaPool:
    """
    A Consistent hashing pool based on the "Ketama" algorithm.
    """
    def __new__(cls, nodes: list[str]) -> KetamaPool:
        """
        Creates a new consistent hashing pool, using the given `nodes` as keys.
        """

    def add_node(self, node: str):
        """
        Adds a new `node` to the pool.
        """

    def remove_node(self, node: str):
        """
        Remove the given `node` from the pool.
        """

    def get_node(
        self, key: str
    ) -> str:
        """
        Returns the node name which will host the given `key`.
        """



from ._bindings import AssembleResult, Cache, Component, Enhancements

AssembleResult.__module__ = __name__
Cache.__module__ = __name__
Component.__module__ = __name__
Enhancements.__module__ = __name__



from dataclasses import dataclass
from uuid import UUID

@dataclass(frozen=True)
class JavaStackFrame:
    class_name: str
    method: str
    file: str | None
    line: int

class ProguardMapper:
    @staticmethod
    def open(path: str) -> ProguardMapper: ...
    @property
    def uuid(self) -> UUID: ...
    @property
    def has_line_info(self) -> bool: ...
    def remap_method(self, klass: str, method: str) -> tuple[str, str] | None: ...
    def remap_frame(
        self, klass: str, method: str, line: int, parameters: str | None = None
    ) -> list[JavaStackFrame]: ...
